@@ -10,9 +10,9 @@ import numpy as np
 import pandas as pd
 import pytz
 import structlog
-
 from openstf_dbc.data_interface import _DataInterface
 from openstf_dbc.services.write import Write
+from openstf_dbc.utils import genereate_datetime_index
 
 
 class Weather:
@@ -192,7 +192,7 @@ class Weather:
         datetime_start=None,
         datetime_end=None,
         source="optimum",
-        resolution="15T",
+        resolution="15min",
     ):
         """Get weather data from database.
 
@@ -279,7 +279,13 @@ class Weather:
             result.index.name = "datetime"
         else:
             self.logger.warning("No weatherdata found. Returning empty dataframe")
-            return pd.DataFrame()
+            return pd.DataFrame(
+                index=genereate_datetime_index(
+                    start=datetime_start,
+                    end=datetime_end,
+                    freq=resolution,
+                )
+            )
 
         # Create a single dataframe with combined sources
         if combine_sources:
